# New in 0.15.4 (2022-03-28)

## Changes

-   Add peakVI publication reference [#1463].
-   Update notebooks with new install functionality for Colab [#1466].
-   Simplify changing the training plan for pyro [#1470].
-   Optionally scale ELBO by a scalar in {class}`~scvi.train.PyroTrainingPlan` [#1469].

## Bug fixes

## Contributors

-   [@jjhong922]
-   [@adamgayoso]
-   [@vitkl]

[#1463]: https://github.com/YosefLab/scvi-tools/pull/1463
[#1466]: https://github.com/YosefLab/scvi-tools/pull/1466
[#1469]: https://github.com/YosefLab/scvi-tools/pull/1469
[#1470]: https://github.com/YosefLab/scvi-tools/pull/1470
[@adamgayoso]: https://github.com/adamgayoso
[@jjhong922]: https://github.com/jjhong922
[@vitkl]: https://github.com/vitkl
